@@ -8,7 +8,7 @@ use Scalar::Util ();
 package Hydrogen;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 
 use Exporter::Shiny qw( croak fc );
 
@@ -87,6 +87,19 @@ Currying:
     say $hash{Alice};                ## ==> 123
     say $getter->( 'Bob' );          ## ==> 456
 
+Using the C<< $_ >> topic variable:
+
+    use feature 'say';
+    use Hydrogen::Topic::HashRef qw( get set );
+    
+    local $_ = {};
+    
+    set( Alice => 123 );
+    set( Bob   => 456 );
+    
+    say $_->{Alice};                 ## ==> 123
+    say get( 'Bob' );                ## ==> 456
+
 =head1 DESCRIPTION
 
 L<Hydrogen> provides a standard library for doing really simple things in
@@ -105,10 +118,6 @@ make a coderef pointing to Perl's C<< += >> operator!
 
 =item *
 
-L<Hydrogen::Array>
-
-=item *
-
 L<Hydrogen::ArrayRef>
 
 =item *
@@ -117,10 +126,6 @@ L<Hydrogen::Bool>
 
 =item *
 
-L<Hydrogen::Code>
-
-=item *
-
 L<Hydrogen::CodeRef>
 
 =item *
@@ -129,10 +134,6 @@ L<Hydrogen::Counter>
 
 =item *
 
-L<Hydrogen::Hash>
-
-=item *
-
 L<Hydrogen::HashRef>
 
 =item *
@@ -147,6 +148,30 @@ L<Hydrogen::Scalar>
 
 L<Hydrogen::String>
 
+=back
+
+=head2 Prototyped Functions
+
+=over
+
+=item *
+
+L<Hydrogen::Array>
+
+=item *
+
+L<Hydrogen::Code>
+
+=item *
+
+L<Hydrogen::Hash>
+
+=back
+
+=head2 Curry Functions
+
+=over
+
 =item *
 
 L<Hydrogen::Curry::ArrayRef>
@@ -181,6 +206,62 @@ L<Hydrogen::Curry::String>
 
 =back
 
+=head2 Topicalized Functions
+
+=over
+
+=item *
+
+L<Hydrogen::Topic::ArrayRef>
+
+=item *
+
+L<Hydrogen::Topic::Bool>
+
+=item *
+
+L<Hydrogen::Topic::CodeRef>
+
+=item *
+
+L<Hydrogen::Topic::Counter>
+
+=item *
+
+L<Hydrogen::Topic::HashRef>
+
+=item *
+
+L<Hydrogen::Topic::Number>
+
+=item *
+
+L<Hydrogen::Topic::Scalar>
+
+=item *
+
+L<Hydrogen::Topic::String>
+
+=back
+
+=head1 BONUS FUNCTIONS
+
+Hydrogen uses the following functions internally, but they may also be
+useful to you.
+
+=head2 C<< Hydrogen::croak( $message, @args? ) >>
+
+Acts like C<croak> from L<Carp>, but if C<< @args >> is provided, will
+C<sprintf> first. If C<< @args >> contains references, those will be
+dumped using L<Data::Dumper>.
+
+=head2 C<< Hydrogen::fc( $string? ) >>
+
+Acts like C<CORE::fc> if that function is available, and C<CORE::lc>
+otherwise.
+
+If no C<< $string >> is provided, operates on C<< $_ >>.
+
 =head1 BUGS
 
 Please report any bugs to
